package com.me.asteroids;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;

public class Graphics {

    private OrthographicCamera camera;
    private OrthographicCamera uiCamera;

    private ShapeRenderer shapeRenderer;
    private SpriteBatch spriteBatch;
    private SpriteBatch uiSpriteBatch;

    public Graphics() {
        this.camera = new OrthographicCamera();
        this.uiCamera = new OrthographicCamera();

        this.shapeRenderer = new ShapeRenderer();
        this.spriteBatch = new SpriteBatch();
        this.uiSpriteBatch = new SpriteBatch();
    }

    public void initialize() {
        Gdx.gl.glClearColor(0, 0, 0, 1);
    }

    public void reset() {
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);
    }

    public void dispose() {
        shapeRenderer.dispose();
        spriteBatch.dispose();
        uiSpriteBatch.dispose();
    }

    public ShapeRenderer getShapeRenderer() {
        return shapeRenderer;
    }

    public SpriteBatch getSpriteBatch() {
        return spriteBatch;
    }

    public SpriteBatch getUISpriteBatch() {
        return uiSpriteBatch;
    }

    public void updateViewport(float worldWidth, float worldHeight, float uiWidth, float uiHeight) {
        camera.setToOrtho(false, worldWidth, worldHeight);
        uiCamera.setToOrtho(false, uiWidth, uiHeight);

        shapeRenderer.setProjectionMatrix(camera.combined);
        spriteBatch.setProjectionMatrix(camera.combined);
        uiSpriteBatch.setProjectionMatrix(uiCamera.combined);
    }

}
