package com.me.asteroids.systems;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.GlyphLayout;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.me.asteroids.Constants;
import com.me.asteroids.Graphics;
import com.me.asteroids.components.GameDataComponent;
import com.me.common.ecs.Engine;
import com.me.common.ecs.Entity;
import com.me.common.ecs.EntitySystem;

import static com.me.asteroids.Components.GAME_DATA;

public class GameDataRenderSystem extends EntitySystem {

    private SpriteBatch batch;
    private BitmapFont font;
    private GlyphLayout gameOverLayout;

    private GameDataComponent gameData;

    public GameDataRenderSystem(Engine engine, Graphics graphics, BitmapFont font) {
        super(engine, GameDataComponent.class);
        this.batch = graphics.getUISpriteBatch();
        this.font = font;
        this.gameOverLayout = new GlyphLayout(font, "GAME OVER");
    }

    @Override
    public void preProcess() {
        batch.begin();
    }

    @Override
    public void processEntity(Entity entity, float dt) {
        if(gameData == null) {
            gameData = GAME_DATA.get(entity);
        }

        switch (gameData.gameMode) {
            case GAME_OVER:
                font.setColor(Color.RED);
                font.draw(batch, "GAME OVER", Constants.getHalfUIWidth() - (gameOverLayout.width / 2), Constants.getHalfUIHeight() + (font.getCapHeight() / 2));
                break;
            default:
                font.setColor(Color.CHARTREUSE);
                font.draw(batch, "Score: " + gameData.score, 15, Constants.getUIHeight() - 15);
                font.draw(batch, "Lives: " + gameData.lives, 15, Constants.getUIHeight() - font.getCapHeight() - 30);
                break;
        }
    }

    @Override
    public void postProcess() {
        batch.end();
    }

}
